@@ -68,9 +68,10 @@ glade_popup_widget_add_cb (GtkMenuItem *item, RootAddData *data)
 {
   g_return_if_fail (data->adaptor != NULL);
 
-  if (glade_command_create (data->adaptor, data->parent,
-                            data->placeholder, data->project))
-
+  if (glade_command_create (data->adaptor,
+                            data->parent,
+                            data->placeholder,
+                            data->project))
     glade_project_set_add_item (data->project, NULL);
 }
 
