@@ -53,8 +53,8 @@ struct _GladeWidgetActionPrivate
 
 static GParamSpec *properties[N_PROPERTIES];
 
-G_DEFINE_TYPE_WITH_PRIVATE (GladeWidgetAction, glade_widget_action, G_TYPE_OBJECT);
-G_DEFINE_BOXED_TYPE (GladeWidgetActionDef, glade_widget_action_def, glade_widget_action_def_clone, glade_widget_action_def_free);
+G_DEFINE_TYPE_WITH_PRIVATE (GladeWidgetAction, glade_widget_action, G_TYPE_OBJECT)
+G_DEFINE_BOXED_TYPE (GladeWidgetActionDef, glade_widget_action_def, glade_widget_action_def_clone, glade_widget_action_def_free)
 
 static void
 glade_widget_action_init (GladeWidgetAction *object)
@@ -72,10 +72,7 @@ glade_widget_action_finalize (GObject *object)
   GladeWidgetAction *action = GLADE_WIDGET_ACTION (object);
 
   if (action->priv->actions)
-    {
-      g_list_foreach (action->priv->actions, (GFunc) g_object_unref, NULL);
-      g_list_free (action->priv->actions);
-    }
+    g_list_free_full (action->priv->actions, g_object_unref);
 
   G_OBJECT_CLASS (glade_widget_action_parent_class)->finalize (object);
 }
