@@ -47,7 +47,7 @@ static GladeEditableInterface *parent_editable_iface;
 G_DEFINE_TYPE_WITH_CODE (GladeActionEditor, glade_action_editor, GLADE_TYPE_EDITOR_SKELETON,
                          G_ADD_PRIVATE (GladeActionEditor)
                          G_IMPLEMENT_INTERFACE (GLADE_TYPE_EDITABLE,
-                                                glade_action_editor_editable_init));
+                                                glade_action_editor_editable_init))
 
 static void
 glade_action_editor_class_init (GladeActionEditorClass * klass)
