@@ -201,11 +201,12 @@ glade_gtk_assistant_post_create (GladeWidgetAdaptor *adaptor,
   /* Chain Up first */
   GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (GTK_TYPE_WINDOW)->post_create (adaptor, object, reason);
 
-  if (reason == GLADE_CREATE_LOAD)
+  if (project && glade_project_is_loading (project))
     {
-      g_signal_connect (project, "parse-finished",
-                        G_CALLBACK (glade_gtk_assistant_parse_finished),
-                        object);
+      g_signal_connect_object (project, "parse-finished",
+                               G_CALLBACK (glade_gtk_assistant_parse_finished),
+                               object,
+                               0);
     }
   else if (reason == GLADE_CREATE_USER)
     {
