@@ -199,6 +199,7 @@ glade_gtk_grid_post_create (GladeWidgetAdaptor *adaptor,
                             GladeCreateReason   reason)
 {
   GladeWidget *gwidget = glade_widget_get_from_gobject (container);
+  GladeProject *project = glade_widget_get_project (gwidget);
 
   g_signal_connect (G_OBJECT (gwidget), "configure-child",
                     G_CALLBACK (glade_gtk_grid_configure_child), container);
@@ -209,10 +210,11 @@ glade_gtk_grid_post_create (GladeWidgetAdaptor *adaptor,
   g_signal_connect (G_OBJECT (gwidget), "configure-end",
                     G_CALLBACK (glade_gtk_grid_configure_end), container);
 
-  if (reason == GLADE_CREATE_LOAD)
-    g_signal_connect (glade_widget_get_project (gwidget), "parse-finished",
-                      G_CALLBACK (glade_gtk_grid_parse_finished),
-                      container);
+  if (project && glade_project_is_loading (project))
+    g_signal_connect_object (project, "parse-finished",
+                             G_CALLBACK (glade_gtk_grid_parse_finished),
+                             container,
+                             0);
 }
 
 void
@@ -287,6 +289,30 @@ glade_gtk_grid_add_child (GladeWidgetAdaptor *adaptor,
   g_return_if_fail (GTK_IS_GRID (object));
   g_return_if_fail (GTK_IS_WIDGET (child));
 
+  if (!glade_widget_superuser () && !GLADE_IS_PLACEHOLDER (child))
+    {
+      GladeWidget *widget = glade_widget_get_from_gobject (object);
+      GtkGrid *grid = GTK_GRID (object);
+      gint n_columns, n_rows;
+      gint x, y;
+
+      glade_widget_property_get (widget, "n-columns", &n_columns);
+      glade_widget_property_get (widget, "n-rows", &n_rows);
+
+      for (x = 0; x < n_columns; x++)
+        for (y = 0; y < n_rows; y++)
+          {
+            GtkWidget *child_widget = gtk_grid_get_child_at (grid, x, y);
+
+            if (GLADE_IS_PLACEHOLDER (child_widget))
+              {
+                gtk_container_remove (GTK_CONTAINER (grid), child_widget);
+                gtk_grid_attach (grid, GTK_WIDGET (child), x, y, 1, 1);
+                return;
+              }
+          }
+    }
+
   gtk_container_add (GTK_CONTAINER (object), GTK_WIDGET (child));
 
   glade_gtk_grid_refresh_placeholders (GTK_GRID (object), FALSE);
