@@ -81,5 +81,5 @@ glade_gtk_text_buffer_set_property (GladeWidgetAdaptor * adaptor,
     }
   else if (GLADE_PROPERTY_DEF_VERSION_CHECK
            (glade_property_get_def (property), gtk_major_version, gtk_minor_version + 1))
-    GWA_GET_CLASS (G_TYPE_OBJECT)->set_property (adaptor, object, id, value);
+    GLADE_WIDGET_ADAPTOR_GET_ADAPTOR_CLASS (G_TYPE_OBJECT)->set_property (adaptor, object, id, value);
 }
