@@ -29,23 +29,23 @@
 
 gboolean
 glade_gtk_text_tag_table_add_verify (GladeWidgetAdaptor *adaptor,
-				     GtkWidget          *container,
-				     GtkWidget          *child,
-				     gboolean            user_feedback)
+                                     GtkWidget          *container,
+                                     GtkWidget          *child,
+                                     gboolean            user_feedback)
 {
   if (!GTK_IS_TEXT_TAG (child))
     {
       if (user_feedback)
-	{
-	  GladeWidgetAdaptor *tag_adaptor = 
-	    glade_widget_adaptor_get_by_type (GTK_TYPE_TEXT_TAG);
+        {
+          GladeWidgetAdaptor *tag_adaptor = 
+            glade_widget_adaptor_get_by_type (GTK_TYPE_TEXT_TAG);
 
-	  glade_util_ui_message (glade_app_get_window (),
-				 GLADE_UI_INFO, NULL,
-				 ONLY_THIS_GOES_IN_THAT_MSG,
-				 glade_widget_adaptor_get_title (tag_adaptor),
-				 glade_widget_adaptor_get_title (adaptor));
-	}
+          glade_util_ui_message (glade_app_get_window (),
+                                 GLADE_UI_INFO, NULL,
+                                 ONLY_THIS_GOES_IN_THAT_MSG,
+                                 glade_widget_adaptor_get_title (tag_adaptor),
+                                 glade_widget_adaptor_get_title (adaptor));
+        }
 
       return FALSE;
     }
@@ -54,8 +54,9 @@ glade_gtk_text_tag_table_add_verify (GladeWidgetAdaptor *adaptor,
 }
 
 void
-glade_gtk_text_tag_table_add_child (GladeWidgetAdaptor * adaptor,
-				    GObject * container, GObject * child)
+glade_gtk_text_tag_table_add_child (GladeWidgetAdaptor *adaptor,
+                                    GObject            *container, 
+                                    GObject            *child)
 {
   if (GTK_IS_TEXT_TAG (child))
     {
@@ -75,8 +76,9 @@ glade_gtk_text_tag_table_add_child (GladeWidgetAdaptor * adaptor,
 }
 
 void
-glade_gtk_text_tag_table_remove_child (GladeWidgetAdaptor * adaptor,
-				       GObject * container, GObject * child)
+glade_gtk_text_tag_table_remove_child (GladeWidgetAdaptor *adaptor,
+                                       GObject            *container,
+                                       GObject            *child)
 {
   if (GTK_IS_TEXT_TAG (child))
     {
@@ -96,17 +98,18 @@ glade_gtk_text_tag_table_remove_child (GladeWidgetAdaptor * adaptor,
 }
 
 void
-glade_gtk_text_tag_table_replace_child (GladeWidgetAdaptor * adaptor,
-					GObject * container,
-					GObject * current, GObject * new_tag)
+glade_gtk_text_tag_table_replace_child (GladeWidgetAdaptor *adaptor,
+                                        GObject            *container,
+                                        GObject            *current,
+                                        GObject            *new_tag)
 {
   glade_gtk_text_tag_table_remove_child (adaptor, container, current);
   glade_gtk_text_tag_table_add_child (adaptor, container, new_tag);
 }
 
 GList *
-glade_gtk_text_tag_table_get_children (GladeWidgetAdaptor * adaptor,
-				       GObject * container)
+glade_gtk_text_tag_table_get_children (GladeWidgetAdaptor *adaptor,
+                                       GObject            *container)
 {
   GladeWidget *gtable = glade_widget_get_from_gobject (container);
   GList *tags = g_object_get_data (G_OBJECT (gtable), "glade-tags");
@@ -116,23 +119,23 @@ glade_gtk_text_tag_table_get_children (GladeWidgetAdaptor * adaptor,
 
 static void
 glade_gtk_text_tag_table_child_selected (GladeBaseEditor *editor,
-					 GladeWidget *gchild,
-					 gpointer data)
+                                         GladeWidget     *gchild,
+                                         gpointer         data)
 {
   glade_base_editor_add_label (editor, _("Tag"));
-	
+
   glade_base_editor_add_default_properties (editor, gchild);
-	
+
   glade_base_editor_add_label (editor, _("Properties"));
   glade_base_editor_add_editable (editor, gchild, GLADE_PAGE_GENERAL);
 }
 
 static gboolean
 glade_gtk_text_tag_table_move_child (GladeBaseEditor *editor,
-				     GladeWidget *gparent,
-				     GladeWidget *gchild,
-				     gpointer data)
-{	
+                                     GladeWidget     *gparent,
+                                     GladeWidget     *gchild,
+                                     gpointer         data)
+{
   return FALSE;
 }
 
@@ -145,22 +148,22 @@ glade_gtk_text_tag_table_launch_editor (GObject  *table)
 
   /* Editor */
   editor = glade_base_editor_new (glade_widget_get_object (widget), NULL,
-				  _("Tag"), GTK_TYPE_TEXT_TAG,
-				  NULL);
+                                  _("Tag"), GTK_TYPE_TEXT_TAG,
+                                  NULL);
 
   g_signal_connect (editor, "child-selected", G_CALLBACK (glade_gtk_text_tag_table_child_selected), NULL);
   g_signal_connect (editor, "move-child", G_CALLBACK (glade_gtk_text_tag_table_move_child), NULL);
 
   gtk_widget_show (GTK_WIDGET (editor));
-	
+
   window = glade_base_editor_pack_new_window (editor, _("Text Tag Table Editor"), NULL);
   gtk_widget_show (window);
 }
 
 void
 glade_gtk_text_tag_table_action_activate (GladeWidgetAdaptor *adaptor,
-					  GObject *object,
-					  const gchar *action_path)
+                                          GObject            *object,
+                                          const gchar        *action_path)
 {
   if (strcmp (action_path, "launch_editor") == 0)
     {
