@@ -27,14 +27,14 @@
 #include "glade-icon-factory-editor.h"
 
 
-static void glade_icon_factory_editor_finalize (GObject * object);
+static void glade_icon_factory_editor_finalize (GObject *object);
 
-static void glade_icon_factory_editor_editable_init (GladeEditableIface *
+static void glade_icon_factory_editor_editable_init (GladeEditableInterface *
                                                      iface);
 
-static void glade_icon_factory_editor_grab_focus (GtkWidget * widget);
+static void glade_icon_factory_editor_grab_focus (GtkWidget *widget);
 
-static GladeEditableIface *parent_editable_iface;
+static GladeEditableInterface *parent_editable_iface;
 
 G_DEFINE_TYPE_WITH_CODE (GladeIconFactoryEditor, glade_icon_factory_editor,
                          GTK_TYPE_BOX,
@@ -43,7 +43,7 @@ G_DEFINE_TYPE_WITH_CODE (GladeIconFactoryEditor, glade_icon_factory_editor,
 
 
 static void
-glade_icon_factory_editor_class_init (GladeIconFactoryEditorClass * klass)
+glade_icon_factory_editor_class_init (GladeIconFactoryEditorClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
@@ -53,14 +53,14 @@ glade_icon_factory_editor_class_init (GladeIconFactoryEditorClass * klass)
 }
 
 static void
-glade_icon_factory_editor_init (GladeIconFactoryEditor * self)
+glade_icon_factory_editor_init (GladeIconFactoryEditor *self)
 {
   gtk_orientable_set_orientation (GTK_ORIENTABLE (self),
-				  GTK_ORIENTATION_VERTICAL);
+                                  GTK_ORIENTATION_VERTICAL);
 }
 
 static void
-glade_icon_factory_editor_load (GladeEditable * editable, GladeWidget * widget)
+glade_icon_factory_editor_load (GladeEditable *editable, GladeWidget *widget)
 {
   GladeIconFactoryEditor *factory_editor = GLADE_ICON_FACTORY_EDITOR (editable);
   GList *l;
@@ -78,8 +78,8 @@ glade_icon_factory_editor_load (GladeEditable * editable, GladeWidget * widget)
 }
 
 static void
-glade_icon_factory_editor_set_show_name (GladeEditable * editable,
-                                         gboolean show_name)
+glade_icon_factory_editor_set_show_name (GladeEditable *editable,
+                                         gboolean       show_name)
 {
   GladeIconFactoryEditor *factory_editor = GLADE_ICON_FACTORY_EDITOR (editable);
 
@@ -88,7 +88,7 @@ glade_icon_factory_editor_set_show_name (GladeEditable * editable,
 }
 
 static void
-glade_icon_factory_editor_editable_init (GladeEditableIface * iface)
+glade_icon_factory_editor_editable_init (GladeEditableInterface *iface)
 {
   parent_editable_iface = g_type_default_interface_peek (GLADE_TYPE_EDITABLE);
 
@@ -97,7 +97,7 @@ glade_icon_factory_editor_editable_init (GladeEditableIface * iface)
 }
 
 static void
-glade_icon_factory_editor_finalize (GObject * object)
+glade_icon_factory_editor_finalize (GObject *object)
 {
   GladeIconFactoryEditor *factory_editor = GLADE_ICON_FACTORY_EDITOR (object);
 
@@ -112,7 +112,7 @@ glade_icon_factory_editor_finalize (GObject * object)
 }
 
 static void
-glade_icon_factory_editor_grab_focus (GtkWidget * widget)
+glade_icon_factory_editor_grab_focus (GtkWidget *widget)
 {
   GladeIconFactoryEditor *factory_editor = GLADE_ICON_FACTORY_EDITOR (widget);
 
@@ -121,12 +121,12 @@ glade_icon_factory_editor_grab_focus (GtkWidget * widget)
 
 
 GtkWidget *
-glade_icon_factory_editor_new (GladeWidgetAdaptor * adaptor,
-                               GladeEditable * embed)
+glade_icon_factory_editor_new (GladeWidgetAdaptor *adaptor,
+                               GladeEditable      *embed)
 {
   GladeIconFactoryEditor *factory_editor;
   GladeEditorProperty *eprop;
-  GtkWidget *label, *alignment, *frame, *vbox;
+  GtkWidget *label, *description_label, *vbox;
 
   g_return_val_if_fail (GLADE_IS_WIDGET_ADAPTOR (adaptor), NULL);
   g_return_val_if_fail (GLADE_IS_EDITABLE (embed), NULL);
@@ -134,37 +134,33 @@ glade_icon_factory_editor_new (GladeWidgetAdaptor * adaptor,
   factory_editor = g_object_new (GLADE_TYPE_ICON_FACTORY_EDITOR, NULL);
   factory_editor->embed = GTK_WIDGET (embed);
 
-  /* Pack the parent on top... */
-  gtk_box_pack_start (GTK_BOX (factory_editor), GTK_WIDGET (embed), FALSE,
-                      FALSE, 0);
-
   /* Label item in frame label widget on top... */
   eprop =
       glade_widget_adaptor_create_eprop_by_name (adaptor, "sources", FALSE,
                                                  TRUE);
   factory_editor->properties =
       g_list_prepend (factory_editor->properties, eprop);
-  frame = gtk_frame_new (NULL);
-  gtk_frame_set_label_widget (GTK_FRAME (frame), glade_editor_property_get_item_label (eprop));
-  gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
-  gtk_box_pack_start (GTK_BOX (factory_editor), frame, FALSE, FALSE, 12);
 
-  /* Alignment/Vbox in frame... */
-  alignment = gtk_alignment_new (0.5F, 0.5F, 1.0F, 1.0F);
-  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 6, 0, 12, 0);
-  gtk_container_add (GTK_CONTAINER (frame), alignment);
-  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-  gtk_container_add (GTK_CONTAINER (alignment), vbox);
+  label = glade_editor_property_get_item_label (eprop);
 
   /* Add descriptive label */
-  label = gtk_label_new (_("First add a stock name in the entry below, "
-                           "then add and define sources for that icon "
-                           "in the treeview."));
-  gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-  gtk_label_set_line_wrap_mode (GTK_LABEL (label), PANGO_WRAP_WORD);
-  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 8);
+  description_label = gtk_label_new (_("First add a stock name in the entry below, "
+                                       "then add and define sources for that icon "
+                                       "in the treeview."));
+  gtk_label_set_line_wrap (GTK_LABEL (description_label), TRUE);
+  gtk_label_set_line_wrap_mode (GTK_LABEL (description_label), PANGO_WRAP_WORD);
 
-  gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (eprop), FALSE, FALSE, 8);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+  gtk_box_set_spacing (GTK_BOX (vbox), 6);
+
+  gtk_container_add (GTK_CONTAINER (vbox), label);
+  gtk_container_add (GTK_CONTAINER (vbox), description_label);
+  gtk_container_add (GTK_CONTAINER (vbox), GTK_WIDGET (eprop));
+  gtk_widget_set_margin_top (vbox, 6);
+
+  /* Pack the parent on top... */
+  gtk_container_add (GTK_CONTAINER (factory_editor), GTK_WIDGET (embed));
+  gtk_container_add (GTK_CONTAINER (factory_editor), vbox);
 
   gtk_widget_show_all (GTK_WIDGET (factory_editor));
 
