@@ -37,7 +37,7 @@ static GladeEditableInterface *parent_editable_iface;
 G_DEFINE_TYPE_WITH_CODE (GladeRecentChooserEditor, glade_recent_chooser_editor, GLADE_TYPE_EDITOR_SKELETON,
                          G_ADD_PRIVATE (GladeRecentChooserEditor)
                          G_IMPLEMENT_INTERFACE (GLADE_TYPE_EDITABLE,
-                                                glade_recent_chooser_editor_editable_init));
+                                                glade_recent_chooser_editor_editable_init))
 
 static void
 glade_recent_chooser_editor_class_init (GladeRecentChooserEditorClass *klass)
