@@ -33,29 +33,23 @@ struct _GladeScaleEditorPrivate
   GtkWidget *embed;
 };
 
-G_DEFINE_TYPE (GladeScaleEditor, glade_scale_editor, GLADE_TYPE_EDITOR_SKELETON)
+G_DEFINE_TYPE_WITH_PRIVATE (GladeScaleEditor, glade_scale_editor, GLADE_TYPE_EDITOR_SKELETON)
 
 static void
 glade_scale_editor_class_init (GladeScaleEditorClass * klass)
 {
-  GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
   widget_class->grab_focus = glade_scale_editor_grab_focus;
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/gladegtk/glade-scale-editor.ui");
-  gtk_widget_class_bind_template_child_private (widget_class, GladeScaleEditor, embed);
-
-  g_type_class_add_private (object_class, sizeof (GladeScaleEditorPrivate));  
+  gtk_widget_class_bind_template_child_private (widget_class, GladeScaleEditor, embed); 
 }
 
 static void
 glade_scale_editor_init (GladeScaleEditor * self)
 {
-  self->priv = 
-    G_TYPE_INSTANCE_GET_PRIVATE (self,
-				 GLADE_TYPE_SCALE_EDITOR,
-				 GladeScaleEditorPrivate);
+  self->priv = glade_scale_editor_get_instance_private (self);
 
   gtk_widget_init_template (GTK_WIDGET (self));
 }
